@@ -1,9 +1,8 @@
-
 # ------------------------------------------------------------------------------
 
 test_that("test comments", {
   comments_1 <-
-    two_class_set %>%
+    two_class_set |>
     comment_add("none_cart", "What does 'cart' stand for\u2753")
 
   expect_equal(
@@ -15,62 +14,62 @@ test_that("test comments", {
     expect_equal(comments_1$info[[i]]$comment, character(1))
   }
   comments_2 <-
-    comments_1 %>%
+    comments_1 |>
     comment_add("none_cart", "Stuff.")
   expect_equal(
-    comment_get(comments_2, id = "none_cart") %>% paste0(collapse = "\n"),
+    comment_get(comments_2, id = "none_cart") |> paste0(collapse = "\n"),
     "What does 'cart' stand for\u2753\nStuff."
   )
   comments_3 <-
-    comments_2 %>%
+    comments_2 |>
     comment_reset("none_cart")
   expect_equal(
     comments_3$info[[1]]$comment,
     character(1)
   )
   expect_equal(
-    two_class_set %>% comment_add(),
+    two_class_set |> comment_add(),
     two_class_set
   )
   expect_equal(
-    two_class_set %>% comment_add("none_cart"),
+    two_class_set |> comment_add("none_cart"),
     two_class_set
   )
-  expect_error(
-    two_class_set %>% comment_add("toe", "foot"),
-    "The 'id' value is not in wflow_id."
+  expect_snapshot(
+    error = TRUE,
+    two_class_set |> comment_add("toe", "foot")
   )
-  expect_error(
-    two_class_set %>% comment_add(letters, "foot"),
-    "'id' should be a single character value."
+  expect_snapshot(
+    error = TRUE,
+    two_class_set |> comment_add(letters, "foot")
   )
-  expect_error(
-    two_class_set %>% comment_add(1:2, "foot"),
-    "'id' should be a single character value."
+  expect_snapshot(
+    error = TRUE,
+    two_class_set |> comment_add(1:2, "foot")
   )
-  expect_error(
-    two_class_set %>% comment_add("none_cart", 1:2),
-    "The comments should be character strings."
+  expect_snapshot(
+    error = TRUE,
+    two_class_set |> comment_add("none_cart", 1:2)
   )
-  expect_error(
-    comments_1 %>% comment_add("none_cart", "Stuff.", append = FALSE),
-    "There is already a comment for this id and"
+  expect_snapshot(
+    error = TRUE,
+    comments_1 |> comment_add("none_cart", "Stuff.", append = FALSE)
   )
-  expect_error(
-    comment_get(comments_1, id = letters),
-    "should be a single character value"
+  expect_snapshot(
+    error = TRUE,
+    comment_get(comments_1, id = letters)
   )
-  expect_error(
-    comment_get(comments_1, id = letters[1]),
-    "value is not in wflow_id"
+  expect_snapshot(
+    error = TRUE,
+    comment_get(comments_1, id = letters[1])
   )
-  expect_error(
-    comments_1 %>% comment_reset(letters),
-    "should be a single character value"
+  expect_snapshot(
+    error = TRUE,
+    comments_1 |> comment_reset(letters)
   )
-  expect_error(
-    comments_1 %>% comment_reset("none_carts"),
-    "value is not in wflow_id"
+  expect_snapshot(
+    error = TRUE,
+    comments_1 |> comment_reset("none_carts")
   )
 })
 
@@ -80,9 +79,9 @@ test_that("print comments", {
   gatsby_3 <- "Across the courtesy bay the white palaces of fashionable East Egg glittered along the water, and the history of the summer really begins on the evening I drove over there to have dinner with the Tom Buchanans. Daisy was my second cousin once removed and I'd known Tom in college. And just after the war I spent two days with them in Chicago."
 
   test <-
-    two_class_res %>%
-    comment_add("none_cart", gatsby_1) %>%
-    comment_add("none_cart", gatsby_2) %>%
+    two_class_res |>
+    comment_add("none_cart", gatsby_1) |>
+    comment_add("none_cart", gatsby_2) |>
     comment_add("none_glm", gatsby_3)
 
   expect_snapshot(comment_print(test))
